@@ -1,4 +1,4 @@
-/*	$Id: vilter-attachment.c,v 1.62 2006/11/11 13:29:49 mbalmer Exp $	*/
+/*	$Id: vilter-attachment.c,v 1.63 2007/01/06 13:13:25 mbalmer Exp $	*/
 
 /*
  * Copyright (c) 2004, 2005, 2006 Marc Balmer <marc@msys.ch>
@@ -489,43 +489,43 @@ vilter_scan(SMFICTX *ctx, char *fn, size_t fnlen, char *chroot, char *reason,
 				}
 			}
 		} else if (boundary != NULL && mstrlen(m, eom) >= boundary_len + 2) {
-			if (!strncmp(m, "--", 2)) {
-				if (!strncmp(m + 2, boundary, boundary_len)) {
+			if (strncmp(m, "--", 2))
+				goto line;
 
-					/*
-					 * p->end points to the last byte of the part, so
-					 * to write the complete part, one has to write
-					 * p->end - p->start + 1 bytes.
-					 */
+			if (strncmp(m + 2, boundary, boundary_len))
+				goto line;
 
-					if (p != NULL) {
-						p->end = m - 1;
-						lp = p;
-					}
-
-					if ((mstrlen(m, eom) >= boundary_len + 4) &&
-						!strncmp(m + 2 + boundary_len, "--", 2)) {
-							/* end of message */ ;
-					} else {
-						if ((p = malloc(sizeof(struct part))) != NULL) {
-							bzero(p, sizeof(struct part));
-
-							if ((p->start = sol(m, eom)) != NULL) {
-								if (lp == NULL)
-									SLIST_INSERT_HEAD(&parts, p, parts);
-								else
-									SLIST_INSERT_AFTER(lp, p, parts);
-							} else {
-								free(p);
-								p = NULL;
-							}
-						} else
-							syslog(LOG_ERR, "attachment: memory allocation error, not all message parts will be written");
-					}
-				}
+			/*
+			 * p->end points to the last byte of the part, so
+			 * to write the complete part, one has to write
+			 * p->end - p->start + 1 bytes.
+			 */
+			if (p != NULL) {
+				p->end = m - 1;
+				lp = p;
 			}
-		}
 
+			if ((mstrlen(m, eom) >= boundary_len + 4) &&
+			    !strncmp(m + 2 + boundary_len, "--", 2)) {
+				/* end of message */ ;
+			} else {
+				p = malloc(sizeof(struct part));
+				if (p == NULL)
+					syslog(LOG_ERR, "attachment: memory allocation error, not all message parts will be written");
+					goto line;
+				}
+				bzero(p, sizeof(struct part));
+				if ((p->start = sol(m, eom)) != NULL) {
+					if (lp == NULL)
+						SLIST_INSERT_HEAD(&parts, p, parts);
+					else
+						SLIST_INSERT_AFTER(lp, p, parts);
+				} else {
+					free(p);
+					p = NULL;
+				}
+		}
+line:
 		++lines;
 
 		if (mstrlen(m, eom) == 0 && inhdr == 1) {
@@ -545,52 +545,50 @@ vilter_scan(SMFICTX *ctx, char *fn, size_t fnlen, char *chroot, char *reason,
 	if (verbose)
 		warnx("attachment: will skip %d attachments", skip);
 
-	if (skip > 0) {
-		strlcpy(newfn, tmpdir, sizeof(newfn));
-		strlcat(newfn, "/vilter-attachment.XXXXXXXXXX", sizeof(newfn));
-		if ((newfd = mkstemp(newfn)) == -1) {
-			syslog(LOG_ERR, "unable to create temp file");
-			retval = SCAN_ERROR;
-			goto endproc;
-		}
+	if (skip <= 0)
+		goto endproc;
 
-
-		write(newfd, "This is a multi-part message in MIME format."
-		    "\r\n\r\n",
-		    strlen("This is a multi-part message in MIME format."
-		    "\r\n\r\n"));
-		write(newfd, "--", 2);
-		write(newfd, boundary, boundary_len);
-		write(newfd, "\r\n", 2);
-		write(newfd, "Content-Type: text/plain\r\n\r\n",
-		    strlen("Content-Type: text/plain\r\n\r\n"));
-		
-		if (attachment_notification != NULL
-		    && (fp = fopen(attachment_notification, "r")) != NULL) {
-			while ((nread = fread(buf, 1, sizeof(buf), fp)))
-				write(newfd, buf, nread);
-			fclose(fp);
-		} else
-			write(newfd, "Vaporized an unwelcome attachment"
-			    "\r\n\r\n",
-			    strlen("Vaporized an unwelcome attachment"
-			    "\r\n\r\n"));
-
-		SLIST_FOREACH(p, &parts, parts) {
-			if (p->skip == 0 && (p->end - p->start) > 0) {
-				write(newfd, "--", 2);
-				write(newfd, boundary, boundary_len);
-				write(newfd, "\r\n", 2);
-				write(newfd, p->start, p->end - p->start + 1);
-			} 
-		}
-		write(newfd, "--", 2);
-		write(newfd, boundary, boundary_len);
-		write(newfd, "--\r\n", 4);
-		close(newfd);
-		strlcpy(fn, newfn, fnlen);
+	strlcpy(newfn, tmpdir, sizeof(newfn));
+	strlcat(newfn, "/vilter-attachment.XXXXXXXXXX", sizeof(newfn));
+	if ((newfd = mkstemp(newfn)) == -1) {
+		syslog(LOG_ERR, "unable to create temp file");
+		retval = SCAN_ERROR;
+		goto endproc;
 	}
 
+	write(newfd, "This is a multi-part message in MIME format.\r\n\r\n",
+	    strlen("This is a multi-part message in MIME format.\r\n\r\n"));
+	write(newfd, "--", 2);
+	write(newfd, boundary, boundary_len);
+	write(newfd, "\r\n", 2);
+	write(newfd, "Content-Type: text/plain\r\n\r\n",
+	    strlen("Content-Type: text/plain\r\n\r\n"));
+		
+	if (attachment_notification != NULL
+	    && (fp = fopen(attachment_notification, "r")) != NULL) {
+		while ((nread = fread(buf, 1, sizeof(buf), fp)))
+			write(newfd, buf, nread);
+		fclose(fp);
+	} else
+		write(newfd, "Vaporized an unwelcome attachment"
+		    "\r\n\r\n",
+		    strlen("Vaporized an unwelcome attachment"
+		    "\r\n\r\n"));
+
+	SLIST_FOREACH(p, &parts, parts) {
+		if (p->skip == 0 && (p->end - p->start) > 0) {
+			write(newfd, "--", 2);
+			write(newfd, boundary, boundary_len);
+			write(newfd, "\r\n", 2);
+			write(newfd, p->start, p->end - p->start + 1);
+		} 
+	}
+	write(newfd, "--", 2);
+	write(newfd, boundary, boundary_len);
+	write(newfd, "--\r\n", 4);
+	close(newfd);
+	strlcpy(fn, newfn, fnlen);
+
 endproc:
 	if (munmap(msg, statbuf.st_size)) {
 		syslog(LOG_ERR, "attachment: can't munmap file");
