@@ -1,4 +1,4 @@
-/*	$Id: pathnames.h,v 1.3 2006/02/08 16:48:14 mbalmer Exp $	*/
+/*	$Id: pathnames.h,v 1.4 2006/02/19 17:29:41 mbalmer Exp $	*/
 
 /*
  * Copyright (c) 2005, 2006 Marc Balmer <marc@msys.ch>
@@ -16,8 +16,4 @@
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-#ifdef __FreeBSD__
-#define	CLAMD_CONF	"/usr/local/etc/smtp-vilter/clamd.conf"
-#else
 #define	CLAMD_CONF	"/etc/smtp-vilter/clamd.conf"
-#endif
