@@ -1,4 +1,4 @@
-/*	$Id: pathnames.h,v 1.2 2006/02/09 08:48:53 mbalmer Exp $	*/
+/*	$Id: pathnames.h,v 1.3 2006/02/19 17:29:41 mbalmer Exp $	*/
 
 /*
  * Copyright (c) 2004, 2005, 2006 Marc Balmer <marc@msys.ch>
@@ -16,8 +16,4 @@
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-#ifdef __FreeBSD__
-#define	ICAP_CONF	"/usr/local/etc/smtp-vilter/icap.conf"
-#else
 #define	ICAP_CONF	"/etc/smtp-vilter/icap.conf"
-#endif
