@@ -1,4 +1,4 @@
-/*	$Id: engine.c,v 1.65 2006/11/12 11:38:08 mbalmer Exp $	*/
+/*	$Id: engine.c,v 1.66 2007/01/21 13:09:15 mbalmer Exp $	*/
 
 /*
  * Copyright (c) 2003, 2004, 2005, 2006 Marc Balmer <marc@msys.ch>
@@ -76,15 +76,10 @@ extern int	 unwanted_reaction;
 extern int	 clean_reaction;
 
 /* there is only one reaction: add to table */
-
 extern char	*virus_table;
-extern long	 virus_duration;
 extern char	*spam_table;
-extern long	 spam_duration;
 extern char	*unwanted_table;
-extern long	 unwanted_duration;
 extern char	*clean_table;
-extern long	 clean_duration;
 
 extern int	 markall;
 extern int	 logall;
@@ -179,8 +174,8 @@ struct privdata {
 };
 
 #ifdef ENABLE_PF
-static void pf_table_add(const char *, const char *, long);
-static void pf_table_clr(const char *, const char *, long);
+static void pf_table_add(const char *, const char *);
+static void pf_table_clr(const char *, const char *);
 #endif
 static void imsg_commit();
 
@@ -328,7 +323,6 @@ message_cleanup(SMFICTX *ctx)
 			SLIST_REMOVE_HEAD(&msg->rhead, entries);
 			free(r);
 		}
-
 		while (!SLIST_EMPTY(&msg->dhead)) {
 			d = SLIST_FIRST(&msg->dhead);
 			free(d->mailLocalDomain);
@@ -336,7 +330,6 @@ message_cleanup(SMFICTX *ctx)
 			SLIST_REMOVE_HEAD(&msg->dhead, entries);
 			free(d);
 		}
-
 		free(msg->hdrfrom);
 		free(msg->hdrto);
 		free(msg->subject);
@@ -365,7 +358,6 @@ connection_cleanup(SMFICTX *ctx)
 			    &priv->stats, sizeof(priv->stats)) != -1) 
 				imsg_commit();
 		}
-
 		if (priv->conn != NULL) {
 			conn = priv->conn;
 
@@ -1002,14 +994,12 @@ vilter_virus(struct backend *backend, SMFICTX *ctx, struct privdata *priv,
 		switch (virus_reaction) {
 		case REACTION_ADDTBL:
 #ifdef ENABLE_PF
-			pf_table_add(virus_table, priv->conn->hostname,
-			    virus_duration);
+			pf_table_add(virus_table, priv->conn->hostname);
 #endif
 			break;
 		case REACTION_DELTBL:
 #ifdef ENABLE_P
-			pf_table_clr(virus_table, priv->conn->hostname,
-			    virus_duration);
+			pf_table_clr(virus_table, priv->conn->hostname);
 #endif
 			break;
 		}
@@ -1148,14 +1138,12 @@ vilter_spam(struct backend *backend, SMFICTX *ctx, struct privdata *priv,
 		switch (spam_reaction) {
 		case REACTION_ADDTBL:
 #ifdef ENABLE_PF
-			pf_table_add(spam_table, priv->conn->hostname,
-			    spam_duration);
+			pf_table_add(spam_table, priv->conn->hostname);
 #endif
 			break;
 		case REACTION_DELTBL:
 #ifdef ENABLE_PF
-			pf_table_clr(spam_table, priv->conn->hostname,
-			    spam_duration);
+			pf_table_clr(spam_table, priv->conn->hostname);
 #endif
 			break;
 		}
@@ -1272,14 +1260,12 @@ vilter_unwanted(struct backend *backend, SMFICTX *ctx, struct privdata *priv,
 		switch (unwanted_reaction) {
 		case REACTION_ADDTBL:
 #ifdef ENABLE_PF
-			pf_table_add(unwanted_table, priv->conn->hostname,
-			    unwanted_duration);
+			pf_table_add(unwanted_table, priv->conn->hostname);
 #endif
 			break;
 		case REACTION_DELTBL:
 #ifdef ENABLE_PF
-			pf_table_clr(unwanted_table, priv->conn->hostname,
-			    unwanted_duration);
+			pf_table_clr(unwanted_table, priv->conn->hostname);
 #endif
 			break;
 		}
@@ -1415,6 +1401,7 @@ vilter_eom(SMFICTX *ctx)
 	++priv->stats.msgs;
 	msg = priv->msg;
 
+	/* XXX keep the file open and pass the fd to the backends? */
 	fclose(msg->fp);
 	msg->fp = NULL;
 
@@ -1451,14 +1438,12 @@ vilter_eom(SMFICTX *ctx)
 		switch (clean_reaction) {
 		case REACTION_ADDTBL:
 #ifdef ENABLE_PF
-			pf_table_add(clean_table, priv->conn->hostname,
-			    clean_duration);
+			pf_table_add(clean_table, priv->conn->hostname);
 #endif
 			break;
 		case REACTION_DELTBL:
 #ifdef ENABLE_PF
-			pf_table_clr(clean_table, priv->conn->hostname,
-			    clean_duration);
+			pf_table_clr(clean_table, priv->conn->hostname);
 #endif
 			break;
 		}
@@ -1643,7 +1628,7 @@ cleanup:
 
 #ifdef ENABLE_PF
 static void
-pf_table_add(const char *table, const char *addr, long duration)
+pf_table_add(const char *table, const char *addr)
 {
 	pid_t pid;
 	struct pftable_msg m;
@@ -1655,7 +1640,6 @@ pf_table_add(const char *table, const char *addr, long duration)
 
 	strlcpy(m.pftable, table, PFTABLE_LEN);
 	strlcpy(m.addr, addr, ADR_LEN);
-	m.duration = duration;
 	m.len = 0;
 	
 	if (imsg_compose(ibuf_main, IMSG_PFTABLE_ADD, 0, pid, -1, &m,
@@ -1664,7 +1648,7 @@ pf_table_add(const char *table, const char *addr, long duration)
 }
 
 static void
-pf_table_clr(const char *table, const char *addr, long duration)
+pf_table_clr(const char *table, const char *addr)
 {
 	pid_t pid;
 	struct pftable_msg m;
@@ -1676,7 +1660,6 @@ pf_table_clr(const char *table, const char *addr, long duration)
 
 	strlcpy(m.pftable, table, PFTABLE_LEN);
 	strlcpy(m.addr, addr, ADR_LEN);
-	m.duration = duration;
 	m.len = 0;
 	
 	if (imsg_compose(ibuf_main, IMSG_PFTABLE_DEL, 0, pid, -1, &m,
