@@ -1,4 +1,4 @@
-/*	$Id: imsg.c,v 1.4 2006/02/14 20:46:10 mbalmer Exp $ */
+/*	$Id: imsg.c,v 1.6 2006/06/05 17:25:39 mbalmer Exp $ */
 
 /*
  * Copyright (c) 2003, 2004 Henning Brauer <henning@openbsd.org>
@@ -79,8 +79,9 @@ imsg_read(struct imsgbuf *ibuf)
 			ifd->fd = fd;
 			TAILQ_INSERT_TAIL(&ibuf->fds, ifd, entry);
 		} else
-			syslog(LOG_ERR, "imsg_read: got unexpected ctl data level %d "
-			    "type %d", cmsg->cmsg_level, cmsg->cmsg_type);
+			syslog(LOG_ERR, "imsg_read: got unexpected ctl data "
+			    "level %d type %d", cmsg->cmsg_level,
+			    cmsg->cmsg_type);
 	}
 
 	return (n);
@@ -99,8 +100,8 @@ imsg_get(struct imsgbuf *ibuf, struct imsg *imsg)
 	memcpy(&imsg->hdr, ibuf->r.buf, sizeof(imsg->hdr));
 	if (imsg->hdr.len < IMSG_HEADER_SIZE ||
 	    imsg->hdr.len > MAX_IMSGSIZE) {
-		syslog(LOG_ERR, "imsg_get: imsg hdr len %u out of bounds, type=%u",
-		    imsg->hdr.len, imsg->hdr.type);
+		syslog(LOG_ERR, "imsg_get: imsg hdr len %u out of bounds, "
+		    "type=%u", imsg->hdr.len, imsg->hdr.type);
 		return (-1);
 	}
 	if (imsg->hdr.len > av)
@@ -130,7 +131,7 @@ imsg_compose(struct imsgbuf *ibuf, enum imsg_type type, u_int32_t peerid,
 	struct buf	*wbuf;
 	int		 n;
 
-	if ((wbuf = imsg_create(ibuf, type, peerid, pid, datalen)) == NULL)
+	if ((wbuf = imsg_create(type, peerid, pid, datalen)) == NULL)
 		return (-1);
 
 	if (imsg_add(wbuf, data, datalen) == -1)
@@ -145,7 +146,7 @@ imsg_compose(struct imsgbuf *ibuf, enum imsg_type type, u_int32_t peerid,
 }
 
 struct buf *
-imsg_create(struct imsgbuf *ibuf, enum imsg_type type, u_int32_t peerid,
+imsg_create(enum imsg_type type, u_int32_t peerid,
     pid_t pid, u_int16_t datalen)
 {
 	struct buf	*wbuf;
