@@ -1,7 +1,7 @@
-/*	$Id: pftable.c,v 1.25 2006/08/22 13:57:37 mbalmer Exp $ */
+/*	$Id: pftable.c,v 1.26 2007/01/21 13:09:15 mbalmer Exp $ */
 
 /*
- * Copyright (c) 2005, 2006 Marc Balmer <marc@msys.ch>
+ * Copyright (c) 2005 - 2007 Marc Balmer <marc@msys.ch>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -39,16 +39,6 @@
 
 extern int dev;
 
-struct timed_entry {
-	char				*pftable;
-	char				*host;
-	time_t				 expiry;
-	unsigned long			 what;
-	SLIST_ENTRY(timed_entry)	 entries;
-};
-
-SLIST_HEAD(, timed_entry) thead = SLIST_HEAD_INITIALIZER(thead);
-
 int
 pftable_exists(const char *name)
 {
@@ -69,9 +59,9 @@ pftable_exists(const char *name)
 	tio.pfrio_size = 1;
 
 	if (ioctl(dev, DIOCRGETASTATS, &tio) != 0)
-		return (-1);
+		return -1;
 
-	return (0);
+	return 0;
 }
 
 /* imsg handlers */
@@ -184,122 +174,12 @@ pftable_modify(char *pftable, char *host, unsigned long what)
 int
 pftable_addr_add(struct pftable_msg *m)
 {
-	int retval = 0;
-	struct timed_entry *te;
-
-	retval = pftable_modify(m->pftable, m->addr, DIOCRADDADDRS);
-	if (retval || m->duration <= 0)
-		return retval;
-
-	/* Check if there is already an entry for this host */
-	SLIST_FOREACH(te, &thead, entries) {
-		if (!strcmp(te->pftable, m->pftable)
-		    && !strcmp(te->host, m->addr)
-		    && te->what == DIOCRDELADDRS) {
-			time(&te->expiry);
-			te->expiry += (time_t)m->duration;
-			return 0;
-		}
-	}
-
-	/* Add this entry to the timeout list */
-	if ((te = malloc(sizeof(struct timed_entry))) == NULL) {
-		syslog(LOG_ERR, "pftable_modify: memory error");
-		return -1;
-	}
-	bzero(te, sizeof(struct timed_entry));
-	time(&te->expiry);
-	te->expiry += (time_t)m->duration;
-	if ((te->pftable = strdup(m->pftable)) == NULL) {
-		syslog(LOG_ERR, "pftable_modify: memory allocation error");
-		free(te);
-		return -1;
-	}
-	if ((te->host = strdup(m->addr)) == NULL) {
-		syslog(LOG_ERR, "pftable_modify: memory allocation error");
-		free(te->pftable);
-		free(te);
-		return -1;
-	}
-	te->what = DIOCRDELADDRS;
-	SLIST_INSERT_HEAD(&thead, te, entries);
-
-	return retval;
+	return  pftable_modify(m->pftable, m->addr, DIOCRADDADDRS);
 }
 
 int
 pftable_addr_del(struct pftable_msg *m)
 {
-	int retval = 0;
-	struct timed_entry *te;
-
-	retval = pftable_modify(m->pftable, m->addr, DIOCRDELADDRS);
-	if (retval || m->duration <= 0)
-		return retval;
-
-	/* Check if there is already an entry for this host */
-	SLIST_FOREACH(te, &thead, entries) {
-		if (!strcmp(te->pftable, m->pftable)
-		    && !strcmp(te->host, m->addr)
-		    && te->what == DIOCRADDADDRS) {
-			time(&te->expiry);
-			te->expiry += (time_t)m->duration;
-			return 0;
-		}
-	}
-
-	/* Add this entry to the timeout list */
-	if ((te = malloc(sizeof(struct timed_entry))) == NULL) {
-		syslog(LOG_ERR, "pftable_modify: memory error");
-		return -1;
-	}
-	bzero(te, sizeof(struct timed_entry));
-	time(&te->expiry);
-	te->expiry += (time_t)m->duration;
-	if ((te->pftable = strdup(m->pftable)) == NULL) {
-		syslog(LOG_ERR, "pftable_modify: memory allocation error");
-		free(te);
-		return -1;
-	}
-	if ((te->host = strdup(m->addr)) == NULL) {
-		syslog(LOG_ERR, "pftable_modify: memory allocation error");
-		free(te->pftable);
-		free(te);
-		return -1;
-	}
-	te->what = DIOCRADDADDRS;
-	SLIST_INSERT_HEAD(&thead, te, entries);
-
-	return retval;
-}
-
-int
-pftable_timeout(void)
-{
-	time_t now;
-	struct timed_entry *te, *next;
-	int retval = 0;
-
-	if (SLIST_EMPTY(&thead))
-		return 0;
-
-	time(&now);
-	te = SLIST_FIRST(&thead);
-	while (te != NULL) {
-		next = SLIST_NEXT(te, entries);
-		if (te->expiry <= now) {
-			retval = pftable_modify(te->pftable, te->host,
-			    te->what);
-			SLIST_REMOVE(&thead, te, timed_entry, entries);
-			if (te->pftable != NULL)
-				free(te->pftable);
-			if (te->host != NULL)
-				free(te->host);
-			free(te);
-		}
-		te = next;
-	}
-
-	return retval;
+	return pftable_modify(m->pftable, m->addr, DIOCRDELADDRS);
 }
 #endif
