@@ -1,7 +1,7 @@
-/*	$Id: smtp-vilter.c,v 1.171 2006/11/12 11:38:08 mbalmer Exp $	*/
+/*	$Id: smtp-vilter.c,v 1.172 2007/01/21 13:09:15 mbalmer Exp $	*/
 
 /*
- * Copyright (c) 2003, 2004, 2005, 2006 Marc Balmer <marc@msys.ch>
+ * Copyright (c) 2003 - 2007 Marc Balmer <marc@msys.ch>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -73,13 +73,8 @@ int	 virus_reaction;
 int	 spam_reaction;
 int	 unwanted_reaction;
 int	 clean_reaction;
-long	 virus_duration;
-long	 spam_duration;
-long	 unwanted_duration;
-long	 clean_duration;
 
 /* there is only one reaction type: add to/clr from table */
-
 char	*virus_table;
 char	*spam_table;
 char	*unwanted_table;
@@ -115,7 +110,6 @@ int	 logvirus, logspam, logunwanted;
 int	 keep_tmpfiles;
 
 /* statistics */
-
 u_int32_t	n_conn;
 u_int32_t	n_aborts;
 u_int32_t	n_msgs;
@@ -333,8 +327,6 @@ main(int argc, char *argv[])
 	unwanted_reaction = REACTION_UNSET;
 	clean_reaction = REACTION_UNSET;
 
-	virus_duration = spam_duration = unwanted_duration = clean_duration =
-	    0L;
 	virus_table = spam_table = unwanted_table = clean_table = NULL;
 
 	log_facility = LOG_UNSET;
@@ -914,12 +906,6 @@ main(int argc, char *argv[])
 				if (!child_quit && dispatch_imsg(ibuf_e) == -1)
 					quit = 1;
 			}
-
-#ifdef ENABLE_PF
-			if (pftable_timeout())
-				syslog(LOG_WARNING, "can not timeout pf "
-				    "tables");
-#endif
 			if (child_quit && verbose)
 				warnx("child process terminated");
 
